============
Terms of Use
============
| For `"medium-api"` python package
| Last Updated: 5th February, 2022


Agreement to terms
------------------

These Terms of Use constitute a legally binding agreement made between you, 
whether personally or on behalf of an entity (“you”) and |package_name|
(python package) by |author| (“we,” “us” or “our”), concerning your access to 
and use of the |github_link|, |pypi_link| as well as any other media form, media channel, 
mobile website, associated packages, programs, listings, scripts or mobile 
application related, linked, or otherwise connected thereto (collectively, 
the “|common_term|”).

All the functionalities and values of this |common_term| entirely depends on "Medium 
REST APIs" (|rest_api_link|) on which it is built upon.

You agree that by accessing the |common_term|, you have read, understood, and agree to 
be bound by all of these Terms of Use, including that of Medium REST APIs (|rest_apis_eula|). 
If you do not agree with all of these Terms of Use, then you are expressly prohibited from 
using the |common_term| and you must discontinue use immediately.

Supplemental Terms of Use or documents that may be posted on the |common_term| from 
time to time are hereby expressly incorporated herein by reference. We reserve the 
right, in our sole discretion, to make changes or modifications to these Terms of 
Use at any time and for any reason. 

We will alert you about any changes by updating the “Last updated” date of these 
Terms of Use, and you waive any right to receive specific notice of each such 
change. 

It is your responsibility to periodically review these Terms of Use to stay 
informed of updates. You will be subject to, and will be deemed to have been made 
aware of and to have accepted, the changes in any revised Terms of Use by your 
continued use of the |common_term| after the date such revised Terms of Use are posted. 

The information provided on the |common_term| is not intended for distribution to or 
use by any person or entity in any jurisdiction or country where such distribution 
or use would be contrary to law or regulation or which would subject us to any 
registration requirement within such jurisdiction or country. 

Accordingly, those persons who choose to access the |common_term| from other locations 
do so on their own initiative and are solely responsible for compliance with local 
laws, if and to the extent local laws are applicable.

The |common_term| is intended for users who are at least 18 years old. Persons under 
the age of 18 are not permitted to use the |common_term|.

All users who are minors in the jurisdiction in which they reside 
(generally under the age of 18) must have the permission of, and be directly 
supervised by, their parent or guardian to use the |common_term|. If you are a minor, 
you must have your parent or guardian read and agree to these Terms of Use prior 
to you using the |common_term|.

Intellectual Property Rights
-----------------------------

Unless otherwise indicated, the |common_term| is an open-source property under 
MIT License including all source code, databases, functionality, software, 
audio, video, and text on the |common_term| (collectively, 
the “Content”). 

Trademarks, service marks, templates, web designs, graphic designs, 
themes and logos contained therein (the “Marks”) are owned or controlled by us 
or licensed to us, and are protected by copyright and trademark laws and various 
other intellectual property rights and unfair competition laws of the States, 
foreign jurisdictions, and international conventions. 

The Content and the Marks are provided on the Site “AS IS” for your information 
and personal use only. Except as expressly provided in these Terms of Use, 
no Marks may be copied, reproduced, aggregated, republished, uploaded, posted, 
publicly displayed, encoded, translated, transmitted, distributed, sold, 
licensed, or otherwise exploited for any commercial purpose whatsoever, without 
our express prior written permission.

Provided that you are eligible to use the |common_term|, you are granted a limited 
license to access and use the |common_term| and to download or print a copy of any 
portion of the Content to which you have properly gained access solely for your 
personal, non-commercial use. We reserve all rights not expressly granted to you 
in and to the |common_term|, the Content and the Marks.

User Registration
-----------------

You may be required to register with the Medium APIs (|rest_api_link|). 
You agree to keep your password and API Key confidential and will be responsible 
for all use of your account and password. We reserve the right to remove, reclaim, 
or change a username you select if we determine, in our sole discretion, that 
such username is inappropriate, obscene, or otherwise objectionable.

User Representations
--------------------

By using the |common_term|, you represent and warrant that: 

    1. all registration information you submit will be true, accurate, current, and 
       complete; 

    2. you will maintain the accuracy of such information and promptly update such 
       registration information as necessary;

    3. you have the legal capacity and you agree to comply with these Terms of Use; 

    4. you are not under the age of 13;

    5. not a minor in the jurisdiction in which you reside, or if a minor, 
       you have received parental permission to use the |common_term|; 

    6. you will not use the |common_term| for any illegal or unauthorized purpose; 

    7. your use of the |common_term| will not violate any applicable law or regulation.

If you provide any information that is untrue, inaccurate, not current, or 
incomplete, we have the right to suspend or terminate your account and refuse 
any and all current or future use of the |common_term| (or any portion thereof). 

Prohibited Activities
---------------------

You may not access or use the |common_term| for any purpose other than that for 
which we make the |common_term| available.

As a user of the |common_term|, you agree not to:

    1. make any unauthorized use of the |common_term|, including collecting 
       usernames and/or email addresses of users by electronic or other means for 
       the purpose of sending unsolicited email, or creating user accounts by 
       automated means or under false pretenses.
   
    2. circumvent, disable, or otherwise interfere with security-related features 
       of the |common_term| and Medium's Wesite (https://medium.com), including 
       features that prevent or restrict the use or copying of any Content or 
       enforce limitations on the use of the Medium's Website, |common_term| and/or 
       the Content contained therein.
    
    3. engage in unauthorized framing of or linking to the |common_term|.
   
    4. trick, defraud, or mislead us and other users, especially in any attempt to 
       learn sensitive account information such as user passwords;

    5. make improper use of our support services or submit false reports of abuse 
       or misconduct.

    6. interfere with, disrupt, or create an undue burden on the |common_term| or 
       the networks or services connected to the |common_term|, specifically 
       https://medium.com .

    7. attempt to impersonate another user or person or use the username of another 
       user.
    
    8.  sell or otherwise transfer your profile.
   
    9.  use any information obtained from the |common_term| in order to harass, 
        abuse, or harm another person.

    10. use the |common_term| as part of any effort to compete with us.
   
    11. decipher, decompile, disassemble, or reverse engineer any of the proprietary
        software comprising or in any way making up a part of the |common_term|.

    12. attempt to bypass any measures of the |common_term| designed to prevent or 
        restrict access to the |common_term|, or any portion of the |common_term|,
        specifically Medium APIs (|rest_api_link|).

    13. harass, annoy, intimidate, or threaten any of our employees or agents 
        engaged in providing any portion of the |common_term| to you.

    14. delete the copyright or other proprietary rights notice from any Content.

    15. upload or transmit (or attempt to upload or to transmit) viruses, 
        Trojan horses, or other material, including excessive use of capital 
        letters and spamming (continuous posting of repetitive text), that 
        interferes with any party's uninterrupted use and enjoyment of the 
        |common_term| or modifies, impairs, disrupts, alters, or interferes 
        with the use, features, functions, operation, or maintenance of the 
        |common_term|.

    16. scrape large amount of data from https://medium.com using |common_term| 
        or Medium APIs (|rest_api_link|) such that it violates any of the site's 
        policy, affects it functionalities, or threatens its existence, operations 
        and/or business.

    17. upload or transmit (or attempt to upload or to transmit) any material 
        that acts as a passive or active information collection or transmission 
        mechanism, including without limitation, clear graphics interchange 
        formats (“gifs”), 1x1 pixels, web bugs, cookies, or other similar devices 
        (sometimes referred to as “spyware” or “passive collection mechanisms” 
        or “pcms”).

    18. disparage, tarnish, or otherwise harm, in our opinion, us and/or the 
        |common_term|.

    19. use the |common_term| in a manner inconsistent with any applicable 
        laws or regulations.


User Generated Contributions
----------------------------

The |common_term| may invite you to chat, contribute to, or participate in blogs, 
message boards, online forums, and other functionality, and may provide you with 
the opportunity to create, submit, post, display, transmit, perform, publish, 
distribute, or broadcast content and materials to us, including but not limited to 
text, writings, video, audio, photographs, graphics, comments, suggestions, or 
personal information or other material (collectively, "Contributions"). 

Contributions may be viewable by other users of the |common_term| and through 
third-party websites. As such, any Contributions you transmit may be treated as 
non-confidential and non-proprietary. When you create or make available any 
Contributions, you thereby represent and warrant that:

    - the creation, distribution, transmission, public display, or performance, 
      and the accessing, downloading, or copying of your Contributions do not and 
      will not infringe the proprietary rights, including but not limited to the 
      copyright, patent, trademark, trade secret, or moral rights of any third 
      party.

    - you are the creator and owner of or have the necessary licenses, rights, 
      consents, releases, and permissions to use and to authorize us, the 
      |common_term|, and other users of the |common_term| to use your Contributions 
      in any manner contemplated by the |common_term| and these Terms of Use.

    - you have the written consent, release, and/or permission of each and every 
      identifiable individual person in your Contributions to use the name or 
      likeness of each and every such identifiable individual person to enable 
      inclusion and use of your Contributions in any manner contemplated by the 
      |common_term| and these Terms of Use.

    - your Contributions are not false, inaccurate, or misleading.

    - your Contributions are not unsolicited or unauthorized advertising, 
      promotional materials, pyramid schemes, chain letters, spam, mass mailings, 
      or other forms of solicitation.

    - your Contributions are not obscene, lewd, lascivious, filthy, violent, 
      harassing, libelous, slanderous, or otherwise objectionable (as determined 
      by us).

    - your Contributions do not ridicule, mock, disparage, intimidate, or abuse 
      anyone.

    - your Contributions do not advocate the violent overthrow of any government or 
      incite, encourage, or threaten physical harm against another.

    - your Contributions do not violate any applicable law, regulation, or rule.

    - your Contributions do not violate the privacy or publicity rights of any 
      third party.

    - your Contributions do not contain any material that solicits personal 
      information from anyone under the age of 18 or exploits people under the age 
      of 18 in a sexual or violent manner.

    - your Contributions do not violate any federal or state law concerning child 
      pornography, or otherwise intended to protect the health or well-being of 
      minors;

    - your Contributions do not include any offensive comments that are connected 
      to race, national origin, gender, sexual preference, or physical handicap.

    - your Contributions do not otherwise violate, or link to material that violates, 
      any provision of these Terms of Use, or any applicable law or regulation.

Any use of the |common_term| in violation of the foregoing violates these Terms 
of Use and may result in, among other things, termination or suspension of your 
rights to use the |common_term|.
 
Contribution License
--------------------

By posting your Contributions to any part of the |common_term| or making 
Contributions accessible to the |common_term| by linking your account from the 
|common_term| to any of your social networking accounts, you automatically grant, 
and you represent and warrant that you have the right to grant, to us an 
unrestricted, unlimited, irrevocable, perpetual, non-exclusive, transferable, 
royalty-free, fully-paid, worldwide right, and license to host, use, copy, 
reproduce, disclose, sell, resell, publish, broadcast, retitle, archive, store, 
cache, publicly perform, publicly display, reformat, translate, transmit, excerpt 
(in whole or in part), and distribute such Contributions (including, without 
limitation, your image and voice) for any purpose, commercial, advertising, or 
otherwise, and to prepare derivative works of, or incorporate into other works, 
such Contributions, and grant and authorize sublicenses of the foregoing. 
The use and distribution may occur in any media formats and through any media 
channels. 

This license will apply to any form, media, or technology now known or hereafter 
developed, and includes our use of your name, company name, and franchise name, as 
applicable, and any of the trademarks, service marks, trade names, logos, and 
personal and commercial images you provide. You waive all moral rights in your 
Contributions, and you warrant that moral rights have not otherwise been asserted 
in your Contributions. 

We do not assert any ownership over your Contributions. You retain full ownership 
of all of your Contributions and any intellectual property rights or other 
proprietary rights associated with your Contributions. We are not liable for any 
statements or representations in your Contributions provided by you in any area 
on the |common_term|. 

You are solely responsible for your Contributions to the |common_term| and you 
expressly agree to exonerate us from any and all responsibility and to refrain from 
any legal action against us regarding your Contributions.  

We have the right, in our sole and absolute discretion, 

    (1) to edit, redact, or otherwise change any Contributions; 
    (2) to re-categorize any Contributions to place them in more appropriate 
        locations on the |common_term|; and 
    (3) to pre-screen or delete any Contributions at any time and for any reason, 
        without notice. 
    
We have no obligation to monitor your Contributions. 

Guidelines for Reviews
----------------------

We may provide you areas on the |common_term| to leave reviews or ratings. 
When posting a review, you must comply with the following criteria: 

    (1) you should have firsthand experience with the person/entity being reviewed;

    (2) your reviews should not contain offensive profanity, or abusive, racist, 
        offensive, or hate language; 

    (3) your reviews should not contain discriminatory references based on religion, 
        race, gender, national origin, age, marital status, sexual orientation, 
        or disability; 

    (4) your reviews should not contain references to illegal activity; 

    (5) you should not be affiliated with competitors if posting negative reviews; 

    (6) you should not make any conclusions as to the legality of conduct; 

    (7) you may not post any false or misleading statements; 

    (8) you may not organize a campaign encouraging others to post reviews, 
        whether positive or negative. 

We may accept, reject, or remove reviews in our sole discretion. We have absolutely 
no obligation to screen reviews or to delete reviews, even if anyone considers 
reviews objectionable or inaccurate. Reviews are not endorsed by us, and do not 
necessarily represent our opinions or the views of any of our affiliates or partners. 

We do not assume liability for any review or for any claims, liabilities, or losses 
resulting from any review. By posting a review, you hereby grant to us a perpetual, 
non-exclusive, worldwide, royalty-free, fully-paid, assignable, and sub-licensable 
right and license to reproduce, modify, translate, transmit by any means, display, 
perform, and/or distribute all content relating to reviews.

Submissions
-----------

You acknowledge and agree that any questions, comments, suggestions, ideas, 
feedback, or other information regarding the |common_term| ("Submissions") 
provided by you to us are non-confidential and shall become our sole property. 
We shall own exclusive rights, including all intellectual property rights, 
and shall be entitled to the unrestricted use and dissemination of these Submissions 
for any lawful purpose, commercial or otherwise, without acknowledgment or 
compensation to you. 

You hereby waive all moral rights to any such Submissions, and you hereby warrant 
that any such Submissions are original with you or that you have the right to 
submit such Submissions. You agree there shall be no recourse against us for any 
alleged or actual infringement or misappropriation of any proprietary right in 
your Submissions.

Third-Party Websites And Content
--------------------------------

The |common_term| may contain (or you may be sent via the Site) links to other 
websites ("Third-Party Websites") as well as articles, photographs, text, graphics, 
pictures, designs, music, sound, video, information, applications, software, and 
other content or items belonging to or originating from third parties ("Third-Party 
Content"). 

Such Third-Party Websites and Third-Party Content are not investigated, monitored, 
or checked for accuracy, appropriateness, or completeness by us, and we are not 
responsible for any Third-Party Websites accessed through the Site or any Third-Party 
Content posted on, available through, or installed from the Site, including the 
content, accuracy, offensiveness, opinions, reliability, privacy practices, or 
other policies of or contained in the Third-Party Websites or the Third-Party 
Content. 

Inclusion of, linking to, or permitting the use or installation of any Third-Party 
Websites or any Third-Party Content does not imply approval or endorsement thereof 
by us. If you decide to leave the |common_term| and access the Third-Party Websites 
or to use or install any Third-Party Content, you do so at your own risk, and you 
should be aware these Terms of Use no longer govern. 

You should review the applicable terms and policies, including privacy and data 
gathering practices, of any website to which you navigate from the |common_term| 
or relating to any applications you use or install from the |common_term|. Any 
purchases you make through Third-Party Websites will be through other websites 
and from other companies, and we take no responsibility whatsoever in relation to 
such purchases which are exclusively between you and the applicable third party. 

You agree and acknowledge that we do not endorse the products or services offered 
on Third-Party Websites and you shall hold us harmless from any harm caused by your 
purchase of such products or services. Additionally, you shall hold us harmless 
from any losses sustained by you or harm caused to you relating to or resulting in 
any way from any Third-Party Content or any contact with Third-Party Websites. 

|common_term| Management
-------------------------

We reserve the right, but not the obligation, to: 

    (1) monitor the |common_term| for violations of these Terms of Use; 

    (2) take appropriate legal action against anyone who, in our sole discretion, 
        violates the law or these Terms of Use, including without limitation, 
        reporting such user to law enforcement authorities; 

    (3) in our sole discretion and without limitation, refuse, restrict access 
        to, limit the availability of, or disable (to the extent technologically 
        feasible) any of your Contributions or any portion thereof; 

    (4) in our sole discretion and without limitation, notice, or liability, 
        to remove from the |common_term| or otherwise disable all files and content 
        that are excessive in size or are in any way burdensome to our systems; 

    (5) otherwise manage the |common_term| in a manner designed to protect our 
        rights and property and to facilitate the proper functioning of the 
        |common_term|.

Term And Termination
--------------------

These Terms of Use shall remain in full force and effect while you use the 
|common_term|. 

WITHOUT LIMITING ANY OTHER PROVISION OF THESE TERMS OF USE, WE RESERVE THE RIGHT 
TO, IN OUR SOLE DISCRETION AND WITHOUT NOTICE OR LIABILITY, DENY ACCESS TO AND 
USE OF THE |common_term| (INCLUDING BLOCKING CERTAIN IP ADDRESSES), TO ANY PERSON 
FOR ANY REASON OR FOR NO REASON, INCLUDING WITHOUT LIMITATION FOR BREACH OF ANY 
REPRESENTATION, WARRANTY, OR COVENANT CONTAINED IN THESE TERMS OF USE OR OF ANY 
APPLICABLE LAW OR REGULATION. WE MAY TERMINATE YOUR USE OR PARTICIPATION IN THE 
|common_term| OR DELETE YOUR ACCOUNT AND ANY CONTENT OR INFORMATION THAT YOU POSTED 
AT ANY TIME, WITHOUT WARNING, IN OUR SOLE DISCRETION. 

If we terminate or suspend your account for any reason, you are prohibited from 
registering and creating a new account under your name, a fake or borrowed name, 
or the name of any third party, even if you may be acting on behalf of the third 
party. 

In addition to terminating or suspending your account, we reserve the right to take 
appropriate legal action, including without limitation pursuing civil, criminal, 
and injunctive redress.


Modifications And Interruptions 
--------------------------------

We reserve the right to change, modify, or remove the contents of the |common_term| 
at any time or for any reason at our sole discretion without notice. However, we 
have no obligation to update any information on our |common_term|. We also reserve 
the right to modify or discontinue all or part of the |common_term| without notice 
at any time. 

We will not be liable to you or any third party for any modification, price change, 
suspension, or discontinuance of the |common_term|. 

We cannot guarantee the |common_term| will be available at all times. We may 
experience hardware, software, or other problems or need to perform maintenance 
related to the |common_term|, resulting in interruptions, delays, or errors. 

We reserve the right to change, revise, update, suspend, discontinue, or otherwise 
modify the |common_term| at any time or for any reason without notice to you. 
You agree that we have no liability whatsoever for any loss, damage, or inconvenience 
caused by your inability to access or use the |common_term| during any downtime 
or discontinuance of the |common_term|. 

Nothing in these Terms of Use will be construed to obligate us to maintain and 
support the |common_term| or to supply any corrections, updates, or releases in 
connection therewith.

Governing Law 
--------------

These Terms of Use and your use of the |common_term| are governed by and construed 
in accordance with the Indian National Law applicable to agreements made and to 
be entirely performed within India, without regard to its conflict of law principles.

Dispute Resolution
-------------------

Any legal action of whatever nature brought by either you or us (collectively, 
the “Parties” and individually, a “Party”) shall be commenced or prosecuted in 
the state and federal courts located in India, Madhya Pradesh, and the Parties 
hereby consent to, and waive all defenses of lack of personal jurisdiction and 
forum non conveniens with respect to venue and jurisdiction in such state and 
federal courts. 

Application of the United Nations Convention on Contracts for the International 
Sale of Goods and the Uniform Computer Information Transaction Act (UCITA) are 
excluded from these Terms of Use. In no event shall any claim, action, or proceeding 
brought by either Party related in any way to the |common_term| be commenced more 
than half a year after the cause of action arose.

Informal Negotiations
^^^^^^^^^^^^^^^^^^^^^^

To expedite resolution and control the cost of any dispute, controversy, or claim 
related to these Terms of Use (each a "Dispute" and collectively, the “Disputes”) 
brought by either you or us (individually, a “Party” and collectively, the “Parties”), 
the Parties agree to first attempt to negotiate any Dispute (except those Disputes 
expressly provided below) informally for at least 90 days before initiating 
arbitration. Such informal negotiations commence upon written notice from one Party 
to the other Party.

Restrictions
^^^^^^^^^^^^^

The Parties agree that any arbitration shall be limited to the Dispute between the 
Parties individually. To the full extent permitted by law, 

   (a) no arbitration shall be joined with any other proceeding; 

   (b) there is no right or authority for any Dispute to be arbitrated on a 
       class-action basis or to utilize class action procedures; and 

   (c) there is no right or authority for any Dispute to be brought in a purported 
       representative capacity on behalf of the general public or any other persons.

Corrections
------------

There may be information on the |common_term| that contains typographical errors, 
inaccuracies, or omissions that may relate to the |common_term|, including 
descriptions, pricing, availability, and various other information. We reserve the 
right to correct any errors, inaccuracies, or omissions and to change or update 
the information on the |common_term| at any time, without prior notice.

Disclaimer
-----------

THE |common_term| IS PROVIDED ON AN AS-IS AND AS-AVAILABLE BASIS. YOU AGREE THAT 
YOUR USE OF THE |common_term| AND OUR SERVICES WILL BE AT YOUR SOLE RISK. TO THE 
FULLEST EXTENT PERMITTED BY LAW, WE DISCLAIM ALL WARRANTIES, EXPRESS OR IMPLIED, 
IN CONNECTION WITH THE |common_term| AND YOUR USE THEREOF, INCLUDING, WITHOUT 
LIMITATION, THE IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR 
PURPOSE, AND NON-INFRINGEMENT. WE MAKE NO WARRANTIES OR REPRESENTATIONS ABOUT THE 
ACCURACY OR COMPLETENESS OF THE |common_term|'s CONTENT OR THE CONTENT OF ANY 
WEBSITES LINKED TO THE |common_term| AND WE WILL ASSUME NO LIABILITY OR 
RESPONSIBILITY FOR ANY 

    (1) ERRORS, MISTAKES, OR INACCURACIES OF CONTENT AND MATERIALS, 
    
    (2) PERSONAL INJURY OR PROPERTY DAMAGE, OF ANY NATURE WHATSOEVER, RESULTING 
        FROM YOUR ACCESS TO AND USE OF THE |common_term|, 
        
    (3) ANY UNAUTHORIZED ACCESS TO OR USE OF OUR SECURE SERVERS AND/OR ANY AND 
        ALL PERSONAL INFORMATION AND/OR FINANCIAL INFORMATION STORED THEREIN, 
        
    (4) ANY INTERRUPTION OR CESSATION OF TRANSMISSION TO OR FROM THE |common_term|, 
    
    (5) ANY BUGS, VIRUSES, TROJAN HORSES, OR THE LIKE WHICH MAY BE TRANSMITTED TO 
        OR THROUGH THE |common_term| BY ANY THIRD PARTY, AND/OR 
        
    (6) ANY ERRORS OR OMISSIONS IN ANY CONTENT AND MATERIALS OR FOR ANY LOSS OR 
        DAMAGE OF ANY KIND INCURRED AS A RESULT OF THE USE OF ANY CONTENT POSTED, 
        TRANSMITTED, OR OTHERWISE MADE AVAILABLE VIA THE |common_term|. 
        
WE DO NOT WARRANT, ENDORSE, GUARANTEE, OR ASSUME RESPONSIBILITY FOR ANY PRODUCT OR 
SERVICE ADVERTISED OR OFFERED BY A THIRD PARTY THROUGH THE |common_term|, ANY 
HYPERLINKED WEBSITE, OR ANY WEBSITE OR MOBILE APPLICATION FEATURED IN ANY BANNER OR 
OTHER ADVERTISING, AND WE WILL NOT BE A PARTY TO OR IN ANY WAY BE RESPONSIBLE FOR 
MONITORING ANY TRANSACTION BETWEEN YOU AND ANY THIRD-PARTY PROVIDERS OF PRODUCTS 
OR SERVICES. 

AS WITH THE PURCHASE OF A PRODUCT OR SERVICE THROUGH ANY MEDIUM OR IN ANY 
ENVIRONMENT, YOU SHOULD USE YOUR BEST JUDGMENT AND EXERCISE CAUTION WHERE 
APPROPRIATE.

Limitations Of Liability
-------------------------

IN NO EVENT WILL WE OR OUR DIRECTORS, EMPLOYEES, OR AGENTS BE LIABLE TO YOU OR 
ANY THIRD PARTY FOR ANY DIRECT, INDIRECT, CONSEQUENTIAL, EXEMPLARY, INCIDENTAL, 
SPECIAL, OR PUNITIVE DAMAGES, INCLUDING LOST PROFIT, LOST REVENUE, LOSS OF DATA, 
OR OTHER DAMAGES ARISING FROM YOUR USE OF THE |common_term|, EVEN IF WE HAVE 
BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES. 

Indemnification
----------------

You agree to defend, indemnify, and hold us harmless, including our subsidiaries, 
affiliates, and all of our respective officers, agents, partners, and employees, 
from and against any loss, damage, liability, claim, or demand, including reasonable 
attorneys' fees and expenses, made by any third party due to or arising out of: 

    (1) your Contributions; 
    
    (2) use of the |common_term|; 
    
    (3) breach of these Terms of Use; 
    
    (4) any breach of your representations and warranties set forth in these 
        Terms of Use; 
        
    (5) your violation of the rights of a third party, including but not limited 
        to intellectual property rights; or 
        
    (6) any overt harmful act toward any other user of the |common_term| with 
        whom you connected via the |common_term|. 

Notwithstanding the foregoing, we reserve the right, at your expense, to assume the 
exclusive defense and control of any matter for which you are required to indemnify 
us, and you agree to cooperate, at your expense, with our defense of such claims. 
We will use reasonable efforts to notify you of any such claim, action, or 
proceeding which is subject to this indemnification upon becoming aware of it.
 
User Data
----------

We will maintain certain data that you transmit to the |common_term| for the purpose 
of managing the |common_term|, as well as data relating to your use of the 
|common_term|. Although we perform regular routine backups of data, you are solely 
responsible for all data that you transmit or that relates to any activity you have 
undertaken using the |common_term|.

You agree that we shall have no liability to you for any loss or corruption of any 
such data, and you hereby waive any right of action against us arising from any 
such loss or corruption of such data.
 
Electronic Communications, Transactions, And Signatures
--------------------------------------------------------

Visiting the |common_term|, sending us emails, and completing online forms 
constitute electronic communications. You consent to receive electronic 
communications, and you agree that all agreements, notices, disclosures, and 
other communications we provide to you electronically, via email and on the 
|common_term|, satisfy any legal requirement that such communication be in writing. 

YOU HEREBY AGREE TO THE USE OF ELECTRONIC SIGNATURES, CONTRACTS, ORDERS, AND OTHER 
RECORDS, AND TO ELECTRONIC DELIVERY OF NOTICES, POLICIES, AND RECORDS OF TRANSACTIONS 
INITIATED OR COMPLETED BY US OR VIA THE SITE.

You hereby waive any rights or requirements under any statutes, regulations, rules, 
ordinances, or other laws in any jurisdiction which require an original signature or 
delivery or retention of non-electronic records, or to payments or the granting of 
credits by any means other than electronic means. 

Miscellaneous
--------------

These Terms of Use and any policies or operating rules posted by us on the 
|common_term| constitute the entire agreement and understanding between you and us. 
Our failure to exercise or enforce any right or provision of these Terms of use 
shall not operate as a waiver of such right or provision.

These Terms of Use operate to the fullest extent permissible by law. We may assign 
any or all of our rights and obligations to others at any time. We shall not be 
responsible or liable for any loss, damage, delay, or failure to act caused by any 
cause beyond our reasonable control.

If any provision or part of a provision of these Terms of Use is determined to be 
unlawful, void, or unenforceable, that provision or part of the provision is deemed 
severable from these Terms of Use and does not affect the validity and enforceability 
of any remaining provisions.

There is no joint venture, partnership, employment or agency relationship created 
between you and us as a result of these Terms of Use or use of the |common_term|. 
You agree that these Terms of Use will not be construed against us by virtue of 
having drafted them. 

You hereby waive any and all defenses you may have based on the electronic form of 
these Terms of Use and the lack of signing by the parties hereto to execute these 
Terms of Use.

Contact Us
-----------

In order to resolve a complaint regarding the |common_term| or to receive further 
information regarding use of the |common_term|, please contact us at: 

| Nishu Jain
| nishujain1997.19@gmail.com


.. |package_name| replace:: **medium-api**
.. |author| replace:: nishu-jain/weeping-angel/Sanskar Jain
.. |common_term| replace:: *Package*
.. |github_link| replace:: https://github.com/weeping-angel/medium-api
.. |pypi_link| replace:: https://pypi.org/project/medium-api/
.. |rest_api_link| replace:: https://rapidapi.com/nishujain199719-vgIfuFHZxVZ/api/medium2
.. |rest_apis_eula| replace:: https://github.com/weeping-angel/medium-api/raw/pages/terms_of_use.pdf